@@ -118,7 +118,7 @@ qx.Class.define("callbackery.ui.form.renderer.NoteForm", {
                     var copyFailMsg = itemOptions[i].copyFailMsg
                         ? that.xtr(itemOptions[i].copyFailMsg)
                         : that.tr("Select %1 and press [ctrl]+[c]",labelName);
-                    var copySuccessMsg = itemOptions[i].copySuccessMsg ?
+                    var copySuccessMsg = itemOptions[i].copySuccessMsg
                         ? that.xtr(itemOptions[i].copySuccessMsg)
                         : that.tr("%1 copied",labelName);
 
